---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

* **What is the current behaviour?**


* **Please provide the steps to reproduce and if possible a minimal demo of the problem**


* **What is the expected behaviour?**


* **What is the motivation / use case for changing the behaviour? That is, what does this bug prevent PySketcher users from doing?**


* **Please tell us about your environment:**
  
  - Version: 0.0.10
  - OS: [all | Linux | MacOS | Windows ]
  - Python Version: [all | 3.8 | 3.9 | 3.10]

* **Other information** (e.g. detailed explanation, stacktraces, related issues, suggestions how to fix, links for us to have context, eg. stackoverflow, gitter, etc)
